SET FOREIGN_KEY_CHECKS=0;
-- ----------------------------
-- Table structure for alarm_event
-- ----------------------------
CREATE TABLE `alarm_event` (
  `id` int(20) NOT NULL auto_increment,
  `dt_event` datetime default NULL,
  `event` varchar(255) NOT NULL default '',
  `site` varchar(4) NOT NULL default '',
  `MessageType` char(2) default NULL,
  `EventQualifyer` char(1) default NULL,
  `EventCode` char(3) default NULL,
  `Group` char(2) default NULL,
  `Zone` char(3) default NULL,
  `timestamp` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `site` (`site`,`Zone`),
  KEY `site_2` (`site`),
  KEY `event` (`event`),
  KEY `MessageType` (`MessageType`),
  KEY `EventQualifyer` (`EventQualifyer`),
  KEY `EventCode` (`EventCode`),
  KEY `Group` (`Group`),
  KEY `Zone` (`Zone`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
DELIMITER ;;
CREATE TRIGGER `insab` BEFORE INSERT ON `alarm_event` FOR EACH ROW        BEGIN
  
  set NEW.site = SUBSTRING(NEW.event,1,4);
  set NEW.MessageType = SUBSTRING(NEW.event,5,2);
  set NEW.EventQualifyer = SUBSTRING(NEW.event,7,1);
  set NEW.EventCode = SUBSTRING(NEW.event,8,3);
  set NEW.Group = SUBSTRING(NEW.event,11,2);
  set NEW.Zone = SUBSTRING(NEW.event,13,3);
  set NEW.dt_event = now();
END;;
DELIMITER ;
DELIMITER ;;
CREATE TRIGGER `insaa` AFTER INSERT ON `alarm_event` FOR EACH ROW       BEGIN
  
  declare done int default 0;
  declare action varchar(255);
  declare details varchar(255);
  declare stop varchar(255);

  
  
  DECLARE ctrig cursor for SELECT triggers.action, triggers.details, triggers.stop FROM triggers
  WHERE (triggers.site = NEW.site or triggers.site is null or triggers.site = '')
  AND (triggers.messagetype = NEW.messagetype or triggers.messagetype is null or triggers.messagetype = '')
  AND (triggers.eventqualifyer = NEW.eventqualifyer or triggers.eventqualifyer is null or triggers.eventqualifyer = '')
  AND (triggers.eventcode = NEW.eventcode or triggers.eventcode is null or triggers.eventcode = '')
  AND (triggers.eventgroup = SUBSTRING(NEW.event,8,2) or triggers.eventgroup is null or triggers.eventgroup = '')
  AND (triggers.group = NEW.Group or triggers.group is null or triggers.group = '') 
  AND (triggers.zone = NEW.zone or triggers.zone is null or triggers.zone = '')
  ORDER by sequence
  ;
  DECLARE CONTINUE HANDLER FOR SQLSTATE '02000' SET done = 1;
  OPEN ctrig;
  REPEAT
	  FETCH ctrig into action,details,stop;
	  IF NOT done THEN
	  	insert into output_events (action,details,event_id) VALUES (action,details,NEW.id);
	  END IF;
	  IF stop = 1 THEN
	  	set done = 1;
	  END IF;
  UNTIL done END REPEAT;
  CLOSE ctrig;
END;;
DELIMITER ;

-- ----------------------------
-- Table structure for areas
-- ----------------------------
CREATE TABLE `areas` (
  `id` int(11) NOT NULL auto_increment,
  `site` char(4) NOT NULL,
  `zone` char(3) NOT NULL,
  `Description` varchar(255) NOT NULL,
  `timestamp` timestamp NOT NULL default '0000-00-00 00:00:00' on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `site` (`site`,`zone`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for event_groups
-- ----------------------------
CREATE TABLE `event_groups` (
  `id` int(10) NOT NULL auto_increment,
  `group` char(2) default NULL,
  `description` varchar(255) default NULL,
  `timestamp` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `group` (`group`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for event_types
-- ----------------------------
CREATE TABLE `event_types` (
  `id` int(10) NOT NULL auto_increment,
  `eventcode` char(255) default NULL,
  `description` varchar(255) default NULL,
  `Reference` varchar(255) default NULL,
  `timestamp` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `eventcode` (`eventcode`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for output_events
-- ----------------------------
CREATE TABLE `output_events` (
  `id` int(20) NOT NULL auto_increment,
  `action` varchar(255) NOT NULL,
  `details` varchar(255) NOT NULL,
  `cause` varchar(255) default NULL,
  `description` varchar(255) default NULL,
  `event_id` int(11) NOT NULL,
  `ack` datetime default NULL,
  `attempts` int(11) default '0',
  `timestamp` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `action` (`action`,`ack`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;
DELIMITER ;;
CREATE TRIGGER `opins` BEFORE INSERT ON `output_events` FOR EACH ROW            BEGIN

set @opid = NEW.event_id;

set @zt = (select event_types.Reference from event_types,alarm_event
where alarm_event.id = @opid
and event_types.eventcode = alarm_event.eventcode);

if @zt = 'Zone' THEN
	set NEW.cause = IFNULL((select areas.description from areas, event_types,alarm_event
	  where alarm_event.id = @opid
	  and alarm_event.zone = areas.zone
	  and alarm_event.eventcode = event_types.eventcode
	  and event_types.Reference = 'Zone'),'');
end if;
if @zt = 'User' THEN
	set NEW.cause = IFNULL((select users.description from users, event_types,alarm_event   
	  where alarm_event.id = @opid
	  and alarm_event.zone = users.user   
	  and alarm_event.eventcode = event_types.eventcode    and event_types.Reference = 'User'),'');
END IF;
	set NEW.description = IFNULL((select event_types.description from event_types,alarm_event   
	  where alarm_event.id = @opid
	  and alarm_event.eventcode = event_types.eventcode),'');

END;;
DELIMITER ;

-- ----------------------------
-- Table structure for site
-- ----------------------------
CREATE TABLE `site` (
  `id` int(20) NOT NULL auto_increment,
  `code` varchar(4) NOT NULL default '',
  `Name` varchar(255) NOT NULL default '',
  `timestamp` timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `code` (`code`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for triggers
-- ----------------------------
CREATE TABLE `triggers` (
  `id` int(20) NOT NULL auto_increment,
  `site` char(4) default NULL,
  `messagetype` char(2) default NULL,
  `eventqualifyer` char(1) default NULL,
  `eventcode` char(3) default NULL,
  `eventgroup` char(2) default NULL,
  `group` char(2) default NULL,
  `zone` char(3) default NULL,
  `sequence` int(11) default NULL,
  `stop` int(11) default NULL,
  `action` varchar(255) NOT NULL,
  `details` varchar(255) NOT NULL,
  `timestamp` timestamp NULL default NULL on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `site` (`site`),
  KEY `messagetype` (`messagetype`),
  KEY `eventqualifyer` (`eventqualifyer`),
  KEY `eventcode` (`eventcode`),
  KEY `eventgroup` (`eventgroup`),
  KEY `group` (`group`),
  KEY `group_2` (`group`),
  KEY `zone` (`zone`),
  KEY `sequence` (`sequence`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- Table structure for users
-- ----------------------------
CREATE TABLE `users` (
  `id` int(11) NOT NULL auto_increment,
  `site` char(4) NOT NULL,
  `user` char(3) NOT NULL,
  `Description` varchar(255) NOT NULL,
  `timestamp` timestamp NULL default '0000-00-00 00:00:00' on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (`id`),
  KEY `site` (`site`,`user`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

-- ----------------------------
-- View structure for events_with_groups
-- ----------------------------
CREATE ALGORITHM=UNDEFINED DEFINER=`root`@`%` SQL SECURITY DEFINER VIEW `events_with_groups` AS select `event_types`.`eventcode` AS `eventcode`,`event_types`.`description` AS `description`,`event_types`.`id` AS `id`,`event_groups`.`group` AS `group`,`event_groups`.`description` AS `group_desc` from (`event_types` left join `event_groups` on((substr(`event_types`.`eventcode`,1,2) = `event_groups`.`group`)));

-- ----------------------------
-- Records 
-- ----------------------------
INSERT INTO `areas` VALUES ('1', '1234', '001', 'Area One', '2006-07-29 08:04:21');
INSERT INTO `areas` VALUES ('2', '1234', '002', 'Area 2', '2006-07-29 08:08:23');
INSERT INTO `event_groups` VALUES ('2', '10', 'Medical Alarm', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('1', '11', 'Fire Alarms', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('3', '12', 'Panic', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('4', '13', 'Burglar Alarms', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('5', '14', 'General Alarm', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('6', '20', 'Fire Supervisory', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('7', '30', 'System Troubles', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('8', '32', 'Sounder Relay Trouble', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('9', '33', 'System Peripheral Trouble', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('10', '35', 'Communication Trouble', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('11', '37', 'Protection Loop', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('12', '38', 'Sensor Trouble', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('13', '44', 'Close', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('14', '45', 'Remote Access', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('15', '40', 'Open', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('16', '41', 'Remote Access', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('17', '42', 'Access Control', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('18', '50', 'System Disables', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('19', '60', 'Test / Misc', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('20', '65', 'Misc', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('21', '15', '24 Hr Non Burglary', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('22', '16', '24 Hr Non Burglary', '0000-00-00 00:00:00');
INSERT INTO `event_groups` VALUES ('23', '31', 'System Troubles', '2006-07-17 14:54:42');
INSERT INTO `event_groups` VALUES ('24', '34', 'System Peripheral Trouble', '2006-07-17 14:54:47');
INSERT INTO `event_groups` VALUES ('25', '39', 'Sensor Trouble', '2006-07-17 14:54:59');
INSERT INTO `event_groups` VALUES ('26', '46', 'Remote Access', '2006-07-17 14:55:36');
INSERT INTO `event_groups` VALUES ('27', '43', 'Access Control', '2006-07-17 14:55:24');
INSERT INTO `event_groups` VALUES ('28', '52', 'Sounder / Relay Trouble', '2006-07-17 14:55:57');
INSERT INTO `event_groups` VALUES ('29', '53', 'Sounder / Relay Trouble', '2006-07-17 14:56:04');
INSERT INTO `event_groups` VALUES ('30', '55', 'Communications Disables', '2006-07-17 14:56:43');
INSERT INTO `event_groups` VALUES ('31', '57', 'Bypasses', '2006-07-17 14:56:49');
INSERT INTO `event_groups` VALUES ('32', '64', 'Personnel Monitoring', '2006-07-17 14:57:24');
INSERT INTO `event_groups` VALUES ('35', '61', 'Test / Misc', '2006-07-17 14:56:56');
INSERT INTO `event_groups` VALUES ('36', '62', 'Event Log', '2006-07-17 14:57:13');
INSERT INTO `event_groups` VALUES ('37', '63', 'Scheduling', '2006-07-17 14:57:17');
INSERT INTO `event_types` VALUES ('655', '100', 'Medical', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('656', '101', 'Personal Emergency', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('657', '102', 'Fail to report in', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('658', '110', 'Fire', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('659', '111', 'Smoke', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('660', '112', 'Combustion', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('661', '113', 'Water flow', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('662', '114', 'Heat', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('663', '115', 'Pull Station', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('664', '116', 'Duct', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('665', '117', 'Flame', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('666', '118', 'Near Alarm', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('667', '120', 'Panic', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('668', '121', 'Duress', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('669', '122', 'Silent', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('670', '123', 'Audible', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('671', '124', 'Duress – Access granted', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('672', '125', 'Duress – Egress granted', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('673', '130', 'Burglary', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('674', '131', 'Perimeter', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('675', '132', 'Interior', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('676', '133', '24 Hour (Safe)', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('677', '134', 'Entry/Exit', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('678', '135', 'Day/night', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('679', '136', 'Outdoor', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('680', '137', 'Tamper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('681', '138', 'Near alarm', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('682', '139', 'Intrusion Verifier', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('683', '140', 'General Alarm', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('684', '141', 'Polling loop open', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('685', '142', 'Polling loop short', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('686', '143', 'Expansion module failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('687', '144', 'Sensor tamper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('688', '145', 'Expansion module tamper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('689', '146', 'Silent Burglary', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('690', '147', 'Sensor Supervision Failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('691', '150', '24 Hour Non-Burglary', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('692', '151', 'Gas detected', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('693', '152', 'Refrigeration', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('694', '153', 'Loss of heat', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('695', '154', 'Water Leakage', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('696', '155', 'Foil Break', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('697', '156', 'Day Trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('698', '157', 'Low bottled gas level', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('699', '158', 'High temp', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('700', '159', 'Low temp', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('701', '161', 'Loss of air flow', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('702', '162', 'Carbon Monoxide detected', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('703', '163', 'Tank level', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('704', '200', 'Fire Supervisory', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('705', '201', 'Low water pressure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('706', '202', 'Low CO2', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('707', '203', 'Gate valve sensor', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('708', '204', 'Low water level', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('709', '205', 'Pump activated', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('710', '206', 'Pump failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('711', '300', 'System Trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('712', '301', 'AC Loss', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('713', '302', 'Low system battery', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('714', '303', 'RAM Checksum bad', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('715', '304', 'ROM checksum bad', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('716', '305', 'System reset', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('717', '306', 'Panel programming changed', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('718', '307', 'Self- test failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('719', '308', 'System shutdown', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('720', '309', 'Battery test failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('721', '310', 'Ground fault', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('722', '311', 'Battery Missing/Dead', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('723', '312', 'Power Supply Overcurrent', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('724', '313', 'Engineer Reset', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('725', '320', 'Sounder/Relay', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('726', '321', 'Bell 1', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('727', '322', 'Bell 2', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('728', '323', 'Alarm relay', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('729', '324', 'Trouble relay', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('730', '325', 'Reversing relay', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('731', '326', 'Notification Appliance Ckt. # 3', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('732', '327', 'Notification Appliance Ckt. #4', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('733', '330', 'System Peripheral trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('734', '331', 'Polling loop open', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('735', '332', 'Polling loop short', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('736', '333', 'Expansion module failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('737', '334', 'Repeater failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('738', '335', 'Local printer out of paper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('739', '336', 'Local printer failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('740', '337', 'Exp. Module DC Loss', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('741', '338', 'Exp. Module Low Batt.', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('742', '339', 'Exp. Module Reset', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('743', '341', 'Exp. Module Tamper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('744', '342', 'Exp. Module AC Loss', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('745', '343', 'Exp. Module self-test fail', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('746', '344', 'RF Receiver Jam Detect', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('747', '350', 'Communication trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('748', '351', 'Telco 1 fault', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('749', '352', 'Telco 2 fault', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('750', '353', 'Long Range Radio xmitter fault', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('751', '354', 'Failure to communicate event', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('752', '355', 'Loss of Radio supervision', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('753', '356', 'Loss of central polling', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('754', '357', 'Long Range Radio VSWR problem', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('755', '370', 'Protection loop', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('756', '371', 'Protection loop open', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('757', '372', 'Protection loop short', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('758', '373', 'Fire trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('759', '374', 'Exit error alarm (zone)', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('760', '375', 'Panic trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('761', '376', 'Hold-up trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('762', '377', 'Swinger Trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('763', '378', 'Cross-zone Trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('764', '380', 'Sensor trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('765', '381', 'Loss of supervision - RF', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('766', '382', 'Loss of supervision - RPM', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('767', '383', 'Sensor tamper', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('768', '384', 'RF low battery', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('769', '385', 'Smoke detector Hi sensitivity', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('770', '386', 'Smoke detector Low sensitivity', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('771', '387', 'Intrusion detector Hi sensitivity', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('772', '388', 'Intrusion detector Low sensitivity', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('773', '389', 'Sensor self-test failure', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('774', '391', 'Sensor Watch trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('775', '392', 'Drift Compensation Error', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('776', '393', 'Maintenance Alert', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('777', '400', 'Open/Close', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('778', '401', 'O/C by', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('779', '402', 'Group O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('780', '403', 'Automatic O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('781', '404', 'Late to O/C (Note: use 453, 454 instead )', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('782', '405', 'Deferred O/C (Obsolete- do not use )', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('783', '406', 'Cancel', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('784', '407', 'Remote arm/disarm', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('785', '408', 'Quick arm', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('786', '409', 'Keyswitch O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('787', '441', 'Armed STAY', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('788', '442', 'Keyswitch Armed STAY', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('789', '450', 'Exception O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('790', '451', 'Early O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('791', '452', 'Late O/C', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('792', '453', 'Failed to Open', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('793', '454', 'Failed to Close', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('794', '455', 'Auto-arm Failed', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('795', '456', 'Partial Arm', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('796', '457', 'Exit Error (user)', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('797', '458', 'User on Premises', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('798', '459', 'Recent Close', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('799', '461', 'Wrong Code Entry', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('800', '462', 'Legal Code Entry', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('801', '463', 'Re-arm after Alarm', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('802', '464', 'Auto-arm Time Extended', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('803', '465', 'Panic Alarm Reset', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('804', '466', 'Service On/Off Premises', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('805', '411', 'Callback request made', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('806', '412', 'Successful download/access', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('807', '413', 'Unsuccessful access', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('808', '414', 'System shutdown command received', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('809', '415', 'Dialer shutdown command received', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('810', '416', 'Successful Upload', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('811', '421', 'Access denied', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('812', '422', 'Access report by', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('813', '423', 'Forced Access', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('814', '424', 'Egress Denied', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('815', '425', 'Egress Granted', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('816', '426', 'Access Door propped open', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('817', '427', 'Access point Door Status Monitor trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('818', '428', 'Access point Request To Exit trouble', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('819', '429', 'Access program mode entry', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('820', '430', 'Access program mode exit', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('821', '431', 'Access threat level change', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('822', '432', 'Access relay/trigger fail', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('823', '433', 'Access RTE shunt', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('824', '434', 'Access DSM shunt', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('825', '501', 'Access reader disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('826', '520', 'Sounder/Relay Disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('827', '521', 'Bell 1 disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('828', '522', 'Bell 2 disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('829', '523', 'Alarm relay disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('830', '524', 'Trouble relay disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('831', '525', 'Reversing relay disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('832', '526', 'Notification Appliance Ckt. # 3 disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('833', '527', 'Notification Appliance Ckt. # 4 disable', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('834', '531', 'Module Added', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('835', '532', 'Module Removed', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('836', '551', 'Dialer disabled', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('837', '552', 'Radio transmitter disabled', 'Zone', '2006-07-29 10:58:10');
INSERT INTO `event_types` VALUES ('838', '553', 'Remote Upload/Download disabled', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('839', '570', 'Zone/Sensor bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('840', '571', 'Fire bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('841', '572', '24 Hour bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('842', '573', 'Burg. Bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('843', '574', 'Group bypass', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('844', '575', 'Swinger bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('845', '576', 'Access shunt', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('846', '577', 'Access point bypass', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('847', '601', 'Manual trigger test report', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('848', '602', 'Periodic test report', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('849', '603', 'Periodic RF transmission', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('850', '604', 'Fire test', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('851', '605', 'Status report to follow', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('852', '606', 'Listen- in to follow', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('853', '607', 'Walk test mode', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('854', '608', 'Periodic test - System Trouble Present', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('855', '609', 'Video Xmitter active', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('856', '611', 'Point tested OK', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('857', '612', 'Point not tested', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('858', '613', 'Intrusion Walk Tested', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('859', '614', 'Fire Walk Tested', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('860', '615', 'Panic Walk Tested', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('861', '616', 'Service Request', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('862', '621', 'Event Log reset', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('863', '622', 'Event Log 50% full', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('864', '623', 'Event Log 90% full', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('865', '624', 'Event Log overflow', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('866', '625', 'Time/Date reset', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('867', '626', 'Time/Date inaccurate', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('868', '627', 'Program mode entry', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('869', '628', 'Program mode exit', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('870', '629', '32 Hour Event log marker', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('871', '630', 'Schedule change', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('872', '631', 'Exception schedule change', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('873', '632', 'Access schedule change', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('874', '641', 'Senior Watch Trouble', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('875', '642', 'Latch-key Supervision', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('876', '651', 'Reserved for Ademco Use', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `event_types` VALUES ('877', '652', 'Reserved for Ademco Use', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('878', '653', 'Reserved for Ademco Use', 'User', '2006-07-29 10:58:18');
INSERT INTO `event_types` VALUES ('879', '654', 'System Inactivity', 'Zone', '2006-07-29 10:58:11');
INSERT INTO `site` VALUES ('1', '1234', 'Company Name', '2006-07-29 18:09:53');
INSERT INTO `triggers` VALUES ('4', '1234', '18', null, null, '14', null, null, '100', '0', 'call', 'ZAP/g0/55551212', '2006-07-29 17:44:09');
INSERT INTO `triggers` VALUES ('5', '1234', '18', null, null, null, null, null, '100', '0', 'email', 'email@domain.com', '2006-07-29 17:44:09');
INSERT INTO `users` VALUES ('1', '1234', '1', 'User 1', '2006-07-29 12:13:39');
INSERT INTO `users` VALUES ('2', '1234', '2', 'User 2', '2006-07-29 12:13:39');
